type token =
  | AMPERSAND
  | AT_SIGN
  | CARET
  | CNF
  | COLON
  | COMMA
  | EQUALS
  | EXCLAMATION
  | DOUBLEEXCLAMATION
  | FOF
  | QMF
  | GETS
  | GREATER
  | HOF
  | IF
  | IFF
  | IMPLIES
  | INCLUDE_TOK
  | INPUT_CLAUSE
  | INPUT_FORMULA
  | LAMBDA
  | LBRKT
  | LPAREN
  | MAP_TO
  | MMINUS
  | NAMPERSAND
  | NEQUALS
  | NIFF
  | NVLINE
  | PERIOD
  | PPLUS
  | QUESTION
  | DOUBLEQUESTION
  | RBRKT
  | RPAREN
  | TILDE
  | BOX
  | DIAMOND
  | TOK_FALSE
  | TOK_I
  | TOK_O
  | TOK_INT
  | TOK_REAL
  | TOK_TRUE
  | TOK_TYPE
  | VLINE
  | EOF
  | DTHF
  | DFOF
  | DCNF
  | DFOT
  | Unsigned_integer of (string)
  | Signed_integer of (string)
  | Decimal_part of (string)
  | Real of (string)
  | Atomic_system_word of (string)
  | Distinct_object of (string)
  | Single_quoted of (string)
  | Upper_word of (string)
  | Lower_word of (string)
  | Unrecognized

open Parsing;;
let _ = parse_error;;
# 3 "parser-hotptp/htparser.mly"

open Hol_type
open Term
open Signature
open Lexing

let print_error startpos endpos msg =
  if startpos.pos_lnum = endpos.pos_lnum then
    Printf.printf "line %d, characters %d-%d: %s\n"
      startpos.pos_lnum (startpos.pos_cnum - startpos.pos_bol)
      (endpos.pos_cnum - endpos.pos_bol)
      msg
  else
    Printf.printf "line %d, character %d - line %d, character %d: %s\n"
      startpos.pos_lnum (startpos.pos_cnum - startpos.pos_bol)
      endpos.pos_lnum (endpos.pos_cnum - endpos.pos_bol)
      msg

let terms = ref []
let sigma = ref (new_signature ())
let bound_typevars = ref (Hashtbl.create 17)
let typevar_counter = ref 0
let termroles = ref (Hashtbl.create 3)
let add_fun = ref (fun _ _ -> ())

let reset () = let t= !terms in
               let s= !sigma in
               let r= !termroles in
               terms := [];
               sigma := new_signature ();
               termroles := (Hashtbl.create 3);
               (t,s,r)

let reset_bound_typevars () =
  bound_typevars := Hashtbl.create 17;
  typevar_counter := 0

let add_typevar s =
  Hashtbl.add !bound_typevars s (!typevar_counter);
  typevar_counter := !typevar_counter + 1

let add_term t =
  terms := t :: !terms;
  add_fun := fun n r -> Hashtbl.add !termroles r (n,t)

let add_def (s,t) =
  try (
    let ty = Term.type_of (type_of_symbol !sigma) t in
    add_defined_symbol ~ty:(Some ty) !sigma s t
  ) with Failure msg ->
    begin
      print_string ("\nin definition "^s^":\n"^msg^"\n\n");
      add_defined_symbol !sigma s t
    end;
  add_fun := fun n r -> Hashtbl.add !termroles r (s,t)

let add_const_strict (c,ty) =
  add_uninterpreted_symbol !sigma c ty;
  add_fun := fun n r -> Hashtbl.add !termroles r (c, Symbol c)

let add_const (c,ty) =
  if ty = Signature.bt_type then
    Signature.add_basetype !sigma c
  else
  try (
    let ty2 = type_of_symbol !sigma c in
    (* print_string ("Symbol "^c^": ."^(Hol_type.to_string ty2)^"., ."^(Hol_type.to_string ty)^".\n"); *)
    if not (ty2 = ty)
    then failwith ("add_const: type mismatch for symbol "^c^" and types "^
                   (Hol_type.to_string ty2)^" and "^(Hol_type.to_string ty2))
  ) with Failure _ -> add_const_strict (c,ty)

# 140 "parser-hotptp/htparser.ml"
let yytransl_const = [|
  257 (* AMPERSAND *);
  258 (* AT_SIGN *);
  259 (* CARET *);
  260 (* CNF *);
  261 (* COLON *);
  262 (* COMMA *);
  263 (* EQUALS *);
  264 (* EXCLAMATION *);
  265 (* DOUBLEEXCLAMATION *);
  266 (* FOF *);
  267 (* QMF *);
  268 (* GETS *);
  269 (* GREATER *);
  270 (* HOF *);
  271 (* IF *);
  272 (* IFF *);
  273 (* IMPLIES *);
  274 (* INCLUDE_TOK *);
  275 (* INPUT_CLAUSE *);
  276 (* INPUT_FORMULA *);
  277 (* LAMBDA *);
  278 (* LBRKT *);
  279 (* LPAREN *);
  280 (* MAP_TO *);
  281 (* MMINUS *);
  282 (* NAMPERSAND *);
  283 (* NEQUALS *);
  284 (* NIFF *);
  285 (* NVLINE *);
  286 (* PERIOD *);
  287 (* PPLUS *);
  288 (* QUESTION *);
  289 (* DOUBLEQUESTION *);
  290 (* RBRKT *);
  291 (* RPAREN *);
  292 (* TILDE *);
  293 (* BOX *);
  294 (* DIAMOND *);
  295 (* TOK_FALSE *);
  296 (* TOK_I *);
  297 (* TOK_O *);
  298 (* TOK_INT *);
  299 (* TOK_REAL *);
  300 (* TOK_TRUE *);
  301 (* TOK_TYPE *);
  302 (* VLINE *);
    0 (* EOF *);
  303 (* DTHF *);
  304 (* DFOF *);
  305 (* DCNF *);
  306 (* DFOT *);
  316 (* Unrecognized *);
    0|]

let yytransl_block = [|
  307 (* Unsigned_integer *);
  308 (* Signed_integer *);
  309 (* Decimal_part *);
  310 (* Real *);
  311 (* Atomic_system_word *);
  312 (* Distinct_object *);
  313 (* Single_quoted *);
  314 (* Upper_word *);
  315 (* Lower_word *);
    0|]

let yylhs = "\255\255\
\001\000\001\000\001\000\001\000\001\000\001\000\004\000\006\000\
\005\000\008\000\010\000\010\000\014\000\016\000\016\000\016\000\
\017\000\017\000\017\000\017\000\017\000\017\000\022\000\022\000\
\022\000\022\000\018\000\018\000\019\000\019\000\015\000\015\000\
\027\000\003\000\003\000\003\000\030\000\030\000\030\000\029\000\
\029\000\032\000\032\000\028\000\028\000\033\000\033\000\033\000\
\009\000\011\000\012\000\025\000\025\000\025\000\036\000\036\000\
\024\000\024\000\039\000\039\000\040\000\041\000\041\000\043\000\
\043\000\044\000\044\000\038\000\038\000\038\000\038\000\045\000\
\048\000\048\000\049\000\046\000\051\000\037\000\037\000\037\000\
\052\000\052\000\052\000\053\000\053\000\055\000\055\000\026\000\
\026\000\026\000\056\000\056\000\050\000\054\000\035\000\035\000\
\058\000\058\000\059\000\060\000\060\000\061\000\061\000\062\000\
\062\000\057\000\057\000\057\000\057\000\057\000\066\000\063\000\
\068\000\068\000\069\000\064\000\071\000\065\000\065\000\065\000\
\072\000\072\000\072\000\074\000\074\000\076\000\076\000\073\000\
\073\000\073\000\077\000\077\000\070\000\075\000\023\000\023\000\
\078\000\078\000\080\000\082\000\082\000\082\000\082\000\082\000\
\082\000\082\000\082\000\081\000\081\000\081\000\083\000\083\000\
\084\000\084\000\085\000\085\000\079\000\079\000\079\000\079\000\
\079\000\086\000\087\000\087\000\088\000\088\000\088\000\093\000\
\093\000\089\000\089\000\089\000\089\000\089\000\031\000\031\000\
\031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
\031\000\095\000\095\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\042\000\042\000\042\000\
\042\000\042\000\042\000\098\000\047\000\047\000\067\000\067\000\
\097\000\096\000\096\000\091\000\091\000\090\000\090\000\099\000\
\092\000\092\000\100\000\034\000\034\000\034\000\034\000\034\000\
\101\000\101\000\101\000\101\000\101\000\101\000\102\000\103\000\
\104\000\104\000\007\000\007\000\013\000\013\000\020\000\021\000\
\021\000\021\000\002\000\000\000"

let yylen = "\002\000\
\001\000\002\000\002\000\002\000\002\000\001\000\010\000\010\000\
\010\000\001\000\003\000\001\000\001\000\001\000\003\000\001\000\
\001\000\004\000\001\000\001\000\001\000\001\000\004\000\004\000\
\004\000\004\000\002\000\003\000\001\000\003\000\002\000\001\000\
\001\000\010\000\010\000\010\000\001\000\001\000\001\000\003\000\
\005\000\001\000\001\000\005\000\003\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\003\000\003\000\001\000\002\000\
\001\000\001\000\001\000\001\000\003\000\001\000\001\000\003\000\
\003\000\003\000\001\000\001\000\001\000\001\000\003\000\006\000\
\001\000\003\000\001\000\002\000\001\000\001\000\003\000\004\000\
\001\000\001\000\001\000\001\000\001\000\001\000\003\000\001\000\
\001\000\004\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\003\000\001\000\001\000\003\000\003\000\003\000\
\001\000\001\000\001\000\001\000\001\000\003\000\003\000\006\000\
\001\000\003\000\001\000\002\000\001\000\001\000\003\000\004\000\
\001\000\001\000\001\000\001\000\001\000\001\000\003\000\001\000\
\001\000\004\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\003\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\003\000\003\000\
\003\000\003\000\003\000\003\000\001\000\001\000\001\000\001\000\
\003\000\006\000\006\000\006\000\004\000\002\000\003\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\003\000\001\000\001\000\001\000\002\000\003\000\001\000\001\000\
\001\000\001\000\002\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\006\000\001\000\001\000\001\000\001\000\
\003\000\006\000\006\000\001\000\001\000\001\000\003\000\003\000\
\001\000\003\000\003\000\001\000\001\000\001\000\003\000\003\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\000\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\006\000\000\000\001\000\000\000\000\000\000\000\
\000\000\002\000\003\000\004\000\005\000\000\000\000\000\000\000\
\000\000\236\000\238\000\237\000\000\000\235\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\010\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\082\000\081\000\240\000\241\000\242\000\239\000\000\000\000\000\
\093\000\092\000\051\000\000\000\000\000\055\000\089\000\078\000\
\000\000\088\000\205\000\000\000\206\000\077\000\000\000\049\000\
\070\000\000\000\058\000\059\000\060\000\000\000\000\000\068\000\
\069\000\000\000\000\000\000\000\117\000\207\000\208\000\122\000\
\121\000\000\000\000\000\133\000\132\000\050\000\000\000\000\000\
\096\000\097\000\098\000\000\000\000\000\106\000\107\000\108\000\
\109\000\000\000\129\000\000\000\118\000\000\000\000\000\128\000\
\194\000\213\000\196\000\168\000\191\000\188\000\190\000\212\000\
\000\000\195\000\197\000\189\000\193\000\169\000\000\000\047\000\
\046\000\192\000\048\000\170\000\172\000\000\000\000\000\000\000\
\000\000\000\000\000\000\135\000\000\000\137\000\138\000\000\000\
\000\000\000\000\157\000\158\000\159\000\160\000\000\000\000\000\
\173\000\174\000\000\000\056\000\000\000\012\000\000\000\084\000\
\085\000\000\000\000\000\000\000\000\000\000\000\000\000\201\000\
\198\000\200\000\203\000\199\000\202\000\000\000\000\000\000\000\
\000\000\076\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\116\000\124\000\125\000\000\000\000\000\000\000\
\000\000\043\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\146\000\143\000\140\000\
\142\000\145\000\147\000\141\000\144\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\166\000\171\000\054\000\
\000\000\000\000\000\000\000\000\000\000\021\000\000\000\000\000\
\013\000\000\000\016\000\019\000\020\000\022\000\000\000\000\000\
\079\000\000\000\053\000\000\000\000\000\071\000\000\000\064\000\
\061\000\065\000\066\000\000\000\000\000\075\000\110\000\000\000\
\000\000\000\000\115\000\102\000\099\000\103\000\104\000\111\000\
\000\000\119\000\000\000\000\000\000\000\000\000\161\000\000\000\
\000\000\000\000\000\000\000\000\000\000\040\000\000\000\226\000\
\225\000\227\000\228\000\229\000\231\000\230\000\000\000\220\000\
\221\000\222\000\000\000\000\000\000\000\153\000\155\000\151\000\
\139\000\152\000\154\000\156\000\000\000\000\000\000\000\000\000\
\167\000\027\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\032\000\011\000\000\000\009\000\000\000\000\000\
\000\000\007\000\000\000\000\000\008\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\165\000\036\000\034\000\
\035\000\000\000\234\000\233\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\028\000\000\000\000\000\
\000\000\000\000\000\000\033\000\031\000\015\000\000\000\087\000\
\000\000\074\000\000\000\114\000\000\000\127\000\000\000\041\000\
\044\000\224\000\000\000\000\000\000\000\215\000\000\000\000\000\
\000\000\000\000\218\000\030\000\023\000\024\000\025\000\026\000\
\018\000\090\000\072\000\112\000\130\000\162\000\163\000\164\000\
\000\000\219\000"

let yydgoto = "\002\000\
\004\000\150\000\010\000\011\000\012\000\013\000\021\000\030\000\
\063\000\151\000\082\000\047\000\123\000\224\000\052\001\043\001\
\226\000\227\000\044\001\049\000\125\000\230\000\185\000\064\000\
\051\000\052\000\093\001\127\000\128\000\000\000\000\000\129\000\
\215\000\108\001\086\000\053\000\065\000\066\000\067\000\068\000\
\069\000\166\000\070\000\071\000\072\000\073\000\131\000\244\000\
\245\000\055\000\075\000\056\000\154\000\057\000\237\000\058\000\
\088\000\089\000\090\000\091\000\092\000\093\000\094\000\095\000\
\096\000\097\000\098\000\249\000\250\000\099\000\100\000\101\000\
\102\000\182\000\103\000\005\001\104\000\132\000\133\000\134\000\
\135\000\207\000\136\000\137\000\138\000\139\000\140\000\141\000\
\142\000\028\001\143\000\039\001\144\000\145\000\146\000\000\000\
\000\000\000\000\029\001\040\001\024\001\025\001\026\001\077\001"

let yysindex = "\044\000\
\049\255\000\000\000\000\249\255\000\000\040\255\043\255\075\255\
\079\255\000\000\000\000\000\000\000\000\235\255\235\255\235\255\
\235\255\000\000\000\000\000\000\100\255\000\000\126\255\137\255\
\140\255\030\255\030\255\030\255\030\255\149\255\000\000\168\255\
\198\255\219\255\172\002\133\001\072\000\230\000\172\002\081\000\
\000\000\000\000\000\000\000\000\000\000\000\000\232\255\000\000\
\000\000\000\000\000\000\063\255\065\255\000\000\000\000\000\000\
\098\255\000\000\000\000\133\001\000\000\000\000\232\255\000\000\
\000\000\240\255\000\000\000\000\000\000\123\255\193\255\000\000\
\000\000\218\255\133\001\072\000\000\000\000\000\000\000\000\000\
\000\000\232\255\000\000\000\000\000\000\000\000\220\255\077\000\
\000\000\000\000\000\000\004\000\221\255\000\000\000\000\000\000\
\000\000\003\000\000\000\072\000\000\000\195\255\247\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\063\001\000\000\000\000\000\000\000\000\000\000\254\255\000\000\
\000\000\000\000\000\000\000\000\000\000\232\255\232\255\232\255\
\010\000\024\000\009\000\000\000\102\255\000\000\000\000\253\255\
\036\000\042\000\000\000\000\000\000\000\000\000\025\000\171\000\
\000\000\000\000\011\000\000\000\142\002\000\000\014\000\000\000\
\000\000\002\000\172\002\002\000\020\000\023\000\133\001\000\000\
\000\000\000\000\000\000\000\000\000\000\133\001\133\001\133\001\
\015\000\000\000\046\000\049\000\015\000\072\000\072\000\072\000\
\072\000\072\000\000\000\000\000\000\000\002\000\002\000\122\001\
\052\000\000\000\067\000\084\000\122\001\056\000\061\000\062\000\
\122\001\016\001\015\000\122\001\122\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\122\001\122\001\122\001\
\122\001\122\001\015\000\122\001\122\001\000\000\000\000\000\000\
\018\000\075\000\076\000\089\000\091\000\000\000\095\000\101\000\
\000\000\114\000\000\000\000\000\000\000\000\000\097\000\000\000\
\000\000\105\000\000\000\128\000\106\000\000\000\115\000\000\000\
\000\000\000\000\000\000\117\000\146\000\000\000\000\000\118\000\
\119\000\151\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\135\000\153\000\125\000\156\000\000\000\122\001\
\016\001\132\000\138\000\139\000\145\000\000\000\016\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\044\255\000\000\
\000\000\000\000\172\000\147\000\170\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\177\000\149\000\150\000\183\000\
\000\000\000\000\184\000\157\000\122\001\133\001\172\002\002\000\
\142\002\163\000\000\000\000\000\142\002\000\000\002\000\002\000\
\000\000\000\000\188\000\015\000\000\000\190\000\015\000\002\000\
\002\000\000\000\016\001\161\000\099\255\000\000\000\000\000\000\
\000\000\154\255\000\000\000\000\016\001\016\001\196\000\015\000\
\162\002\197\000\201\000\015\000\142\002\000\000\173\000\174\000\
\176\000\178\000\181\000\000\000\000\000\000\000\185\000\000\000\
\133\001\000\000\072\000\000\000\186\000\000\000\099\255\000\000\
\000\000\000\000\044\255\044\255\122\001\000\000\000\000\122\001\
\122\001\207\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\169\000\000\000"

let yyrindex = "\000\000\
\005\000\000\000\000\000\218\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\189\000\211\001\
\000\000\000\000\000\000\000\000\038\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\189\000\000\000\
\000\000\023\255\000\000\000\000\000\000\058\255\101\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\189\000\235\001\000\000\000\000\000\000\000\000\059\255\
\000\000\000\000\000\000\114\255\116\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\011\002\000\000\
\000\000\000\000\000\000\000\000\000\000\189\000\012\255\189\000\
\000\000\187\001\000\000\000\000\141\255\000\000\000\000\226\002\
\132\002\047\002\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\043\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\037\255\189\000\
\000\000\104\255\000\000\000\000\000\000\000\000\000\000\226\000\
\000\000\000\000\000\000\191\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\000\000\000\000\000\000\
\000\000\202\000\000\000\000\000\000\000\000\000\000\000\000\000\
\140\002\000\000\000\000\205\000\000\000\079\002\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\042\255\000\000\
\000\000\000\000\000\000\000\000\210\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\214\000\
\000\000\000\000\080\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\084\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\116\002\000\000\000\000\223\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\217\255\045\255\000\000\000\000\203\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000"

let yygindex = "\000\000\
\000\000\007\000\000\000\000\000\000\000\000\000\142\000\179\000\
\000\000\229\255\000\000\000\000\242\255\000\000\000\000\124\255\
\000\000\215\000\238\254\037\000\244\000\000\000\012\000\212\255\
\226\255\132\255\000\000\106\001\000\000\000\000\000\000\137\001\
\251\255\118\255\184\001\000\000\227\255\185\255\000\000\000\000\
\000\000\176\001\000\000\000\000\000\000\000\000\016\000\208\000\
\000\000\105\255\000\000\000\000\000\000\180\255\115\255\000\000\
\163\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\204\000\000\000\103\255\000\000\000\000\
\108\255\000\000\133\255\153\255\000\000\000\000\087\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\064\255\000\000\187\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"

let yytablesize = 1029
let yytable = "\022\000\
\022\000\022\000\022\000\170\000\243\000\054\000\179\000\005\000\
\147\000\054\000\148\000\031\000\031\000\031\000\031\000\157\000\
\225\000\246\000\038\001\251\000\048\000\048\000\083\000\043\000\
\048\000\048\000\030\001\031\001\057\000\233\000\091\001\236\000\
\130\000\002\001\004\001\158\000\032\001\033\001\034\001\035\001\
\036\001\017\000\017\000\052\000\001\000\048\000\243\000\045\000\
\003\000\126\000\216\000\074\000\087\000\045\000\172\000\023\001\
\075\001\057\000\003\001\003\001\048\000\083\000\014\000\062\000\
\095\000\015\000\116\001\076\001\067\000\152\000\017\000\017\000\
\052\000\084\000\124\000\074\000\045\000\234\000\216\000\234\000\
\252\000\253\000\254\000\255\000\000\001\083\000\019\000\240\000\
\020\000\153\000\074\000\087\000\062\000\095\000\241\000\242\000\
\243\000\016\000\190\000\191\000\192\000\017\000\196\000\197\000\
\105\000\026\000\063\000\188\000\198\000\014\000\155\000\075\001\
\084\000\029\000\029\000\087\000\199\000\200\000\201\000\100\000\
\156\000\101\000\076\001\167\000\235\000\054\000\069\001\202\000\
\203\000\204\000\205\000\027\000\074\001\105\001\223\000\063\000\
\084\000\014\000\014\000\232\000\048\000\232\000\028\000\110\001\
\048\000\029\000\136\000\206\000\100\000\124\000\101\000\048\000\
\048\000\048\000\035\000\214\000\023\000\024\000\025\000\083\000\
\083\000\083\000\083\000\083\000\246\000\251\000\075\001\001\001\
\001\001\095\001\096\001\004\001\004\001\036\000\074\000\136\000\
\094\001\076\001\006\001\090\001\124\000\074\000\074\000\074\000\
\103\001\228\000\236\000\236\000\106\001\087\000\087\000\087\000\
\087\000\087\000\107\001\126\001\003\001\003\001\127\001\128\001\
\010\001\180\000\223\000\037\000\014\001\032\000\033\000\034\000\
\219\000\084\000\084\000\084\000\084\000\084\000\084\000\229\000\
\101\001\102\001\084\000\084\000\124\000\181\000\223\000\041\001\
\038\000\124\000\229\000\234\000\223\000\124\000\051\001\027\001\
\124\000\124\000\234\000\234\000\219\000\149\000\168\000\169\000\
\159\000\173\000\124\000\124\000\124\000\124\000\124\000\037\001\
\124\000\124\000\223\000\223\000\006\000\228\000\160\000\161\000\
\162\000\088\001\007\000\008\000\176\000\124\001\009\000\178\000\
\243\000\163\000\177\000\164\000\165\000\183\000\243\000\243\000\
\089\001\054\000\243\000\068\001\189\000\193\000\050\000\050\000\
\085\000\123\001\050\000\050\000\194\000\018\000\195\000\048\000\
\048\000\232\000\223\000\019\000\209\000\020\000\223\000\217\000\
\232\000\232\000\208\000\210\000\124\000\216\000\211\000\050\000\
\231\000\001\001\001\001\042\001\043\000\044\000\238\000\045\000\
\087\001\239\000\019\000\046\000\020\000\074\000\050\000\085\000\
\218\000\219\000\220\000\221\000\043\000\044\000\223\000\045\000\
\046\000\222\000\019\000\046\000\020\000\174\000\008\001\059\000\
\247\000\124\000\048\000\248\000\083\000\228\000\007\001\085\000\
\009\001\228\000\011\001\160\000\161\000\162\000\076\000\012\001\
\013\001\045\001\046\001\084\000\084\000\084\000\163\000\061\000\
\164\000\165\000\050\001\077\000\078\000\079\000\080\000\047\001\
\074\000\048\001\087\000\081\000\027\001\049\001\053\001\041\000\
\114\001\228\000\043\000\044\000\042\000\045\000\054\001\055\001\
\019\000\046\000\020\000\043\000\044\000\056\001\045\000\084\000\
\229\000\019\000\046\000\020\000\057\001\050\000\050\000\050\000\
\058\001\124\000\050\000\061\001\124\000\124\000\059\001\060\001\
\062\001\050\000\050\000\050\000\063\001\064\001\065\001\066\001\
\067\001\085\000\085\000\085\000\085\000\085\000\070\001\071\001\
\072\001\085\000\085\000\105\000\212\000\106\000\073\001\080\001\
\078\001\107\000\059\000\108\000\079\001\081\001\082\001\083\001\
\217\000\109\000\110\000\111\000\084\001\085\001\086\001\112\000\
\097\001\213\000\099\001\104\001\114\000\115\000\116\000\117\000\
\109\001\112\001\061\000\118\000\229\000\113\001\119\000\117\001\
\118\001\120\000\119\001\129\001\120\001\130\001\121\000\121\001\
\122\000\244\000\186\000\122\001\125\001\043\000\044\000\243\000\
\045\000\086\000\091\000\019\000\046\000\020\000\105\000\091\000\
\106\000\073\000\045\000\113\000\107\000\059\000\108\000\126\000\
\091\000\091\000\091\000\214\000\109\000\110\000\111\000\217\000\
\094\000\187\000\112\000\091\000\113\000\091\000\091\000\114\000\
\115\000\116\000\117\000\171\000\091\000\061\000\118\000\175\000\
\092\001\119\000\100\001\098\001\120\000\000\000\115\001\091\000\
\000\000\121\000\000\000\122\000\000\000\000\000\000\000\000\000\
\043\000\044\000\000\000\045\000\000\000\000\000\019\000\046\000\
\020\000\050\000\050\000\050\000\229\000\000\000\015\001\000\000\
\229\000\000\000\050\000\050\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\085\000\085\000\000\000\000\000\016\001\
\017\001\018\001\019\001\000\000\020\001\000\000\000\000\105\000\
\000\000\106\000\000\000\000\000\000\000\107\000\059\000\108\000\
\229\000\021\001\022\001\000\000\000\000\109\000\110\000\111\000\
\000\000\000\000\000\000\112\000\050\000\184\000\085\000\000\000\
\114\000\115\000\116\000\117\000\000\000\000\000\061\000\118\000\
\000\000\000\000\119\000\000\000\000\000\120\000\000\000\000\000\
\000\000\000\000\121\000\000\000\122\000\000\000\000\000\000\000\
\000\000\043\000\044\000\000\000\045\000\000\000\000\000\019\000\
\046\000\020\000\105\000\000\000\106\000\000\000\000\000\000\000\
\107\000\059\000\108\000\000\000\000\000\000\000\000\000\000\000\
\109\000\110\000\111\000\000\000\059\000\000\000\112\000\000\000\
\213\000\000\000\000\000\114\000\115\000\116\000\117\000\000\000\
\000\000\061\000\118\000\060\000\000\000\119\000\000\000\000\000\
\120\000\000\000\000\000\000\000\061\000\121\000\000\000\122\000\
\062\000\000\000\000\000\041\000\043\000\044\000\000\000\045\000\
\042\000\000\000\019\000\046\000\020\000\000\000\000\000\043\000\
\044\000\000\000\045\000\171\000\171\000\019\000\046\000\020\000\
\171\000\171\000\000\000\000\000\000\000\000\000\042\000\000\000\
\000\000\171\000\171\000\171\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\083\000\171\000\171\000\171\000\171\000\
\083\000\091\000\000\000\000\000\000\000\171\000\000\000\000\000\
\000\000\083\000\083\000\083\000\000\000\000\000\000\000\000\000\
\171\000\094\000\000\000\123\000\083\000\091\000\083\000\083\000\
\123\000\131\000\000\000\000\000\000\000\083\000\000\000\000\000\
\000\000\123\000\123\000\123\000\000\000\000\000\000\000\000\000\
\083\000\134\000\000\000\000\000\123\000\131\000\123\000\123\000\
\000\000\000\000\000\000\186\000\186\000\123\000\000\000\000\000\
\186\000\186\000\000\000\000\000\000\000\000\000\000\000\000\000\
\123\000\186\000\186\000\186\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\186\000\186\000\186\000\186\000\
\000\000\000\000\000\000\171\000\171\000\186\000\000\000\150\000\
\000\000\171\000\000\000\000\000\150\000\150\000\042\000\000\000\
\186\000\171\000\171\000\171\000\000\000\150\000\150\000\150\000\
\000\000\000\000\000\000\000\000\171\000\171\000\171\000\171\000\
\150\000\150\000\150\000\150\000\000\000\171\000\000\000\171\000\
\171\000\150\000\000\000\000\000\080\000\171\000\000\000\000\000\
\171\000\080\000\090\000\000\000\150\000\171\000\171\000\171\000\
\000\000\000\000\080\000\080\000\080\000\000\000\000\000\000\000\
\171\000\171\000\171\000\171\000\000\000\080\000\090\000\080\000\
\080\000\171\000\000\000\000\000\120\000\000\000\080\000\000\000\
\000\000\120\000\130\000\000\000\171\000\000\000\000\000\000\000\
\000\000\080\000\120\000\120\000\120\000\149\000\000\000\000\000\
\000\000\149\000\149\000\000\000\131\000\120\000\130\000\120\000\
\120\000\131\000\149\000\149\000\149\000\000\000\120\000\000\000\
\000\000\000\000\131\000\131\000\131\000\149\000\149\000\149\000\
\149\000\120\000\134\000\217\000\000\000\131\000\149\000\131\000\
\131\000\000\000\000\000\000\000\000\000\000\000\131\000\000\000\
\000\000\149\000\000\000\000\000\000\000\000\000\000\000\000\000\
\015\001\131\000\000\000\000\000\218\000\219\000\220\000\221\000\
\043\000\044\000\039\000\045\000\000\000\222\000\019\000\046\000\
\020\000\016\001\017\001\018\001\019\001\000\000\111\001\040\000\
\000\000\000\000\041\000\000\000\000\000\000\000\000\000\042\000\
\000\000\000\000\000\000\021\001\022\001\000\000\043\000\044\000\
\000\000\045\000\148\000\148\000\019\000\046\000\020\000\148\000\
\148\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\148\000\148\000\148\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\148\000\148\000\148\000\148\000\000\000\
\000\000\000\000\000\000\000\000\148\000"

let yycheck = "\014\000\
\015\000\016\000\017\000\075\000\000\000\035\000\100\000\001\000\
\039\000\039\000\040\000\026\000\027\000\028\000\029\000\060\000\
\149\000\169\000\211\000\173\000\035\000\036\000\037\000\012\001\
\039\000\040\000\196\000\197\000\006\001\154\000\049\001\156\000\
\038\000\182\000\183\000\063\000\206\000\207\000\208\000\209\000\
\210\000\005\001\006\001\006\001\001\000\060\000\035\001\006\001\
\000\001\038\000\006\001\036\000\037\000\012\001\082\000\194\000\
\013\001\035\001\182\000\183\000\075\000\076\000\023\001\006\001\
\006\001\023\001\085\001\024\001\046\001\007\001\034\001\035\001\
\035\001\037\000\038\000\060\000\035\001\154\000\034\001\156\000\
\174\000\175\000\176\000\177\000\178\000\100\000\057\001\159\000\
\059\001\027\001\075\000\076\000\035\001\035\001\166\000\167\000\
\168\000\023\001\126\000\127\000\128\000\023\001\001\001\002\001\
\046\001\006\001\006\001\113\000\007\001\006\001\046\001\013\001\
\076\000\034\001\035\001\100\000\015\001\016\001\017\001\006\001\
\023\001\006\001\024\001\001\001\155\000\155\000\009\001\026\001\
\027\001\028\001\029\001\006\001\015\001\035\001\149\000\035\001\
\100\000\034\001\035\001\154\000\155\000\156\000\006\001\080\001\
\159\000\006\001\006\001\046\001\035\001\113\000\035\001\166\000\
\167\000\168\000\006\001\144\000\015\000\016\000\017\000\174\000\
\175\000\176\000\177\000\178\000\060\001\063\001\013\001\182\000\
\183\000\055\001\056\001\064\001\065\001\006\001\159\000\035\001\
\053\001\024\001\184\000\048\001\144\000\166\000\167\000\168\000\
\067\001\149\000\055\001\056\001\035\001\174\000\175\000\176\000\
\177\000\178\000\077\001\109\001\064\001\065\001\112\001\113\001\
\189\000\007\001\217\000\006\001\193\000\027\000\028\000\029\000\
\006\001\173\000\174\000\175\000\176\000\177\000\178\000\013\001\
\064\001\065\001\182\000\183\000\184\000\027\001\006\001\212\000\
\006\001\189\000\024\001\048\001\012\001\193\000\224\000\195\000\
\196\000\197\000\055\001\056\001\034\001\006\001\046\001\022\001\
\001\001\022\001\206\000\207\000\208\000\209\000\210\000\211\000\
\212\000\213\000\034\001\035\001\004\001\217\000\015\001\016\001\
\017\001\046\001\010\001\011\001\001\001\099\001\014\001\005\001\
\004\001\026\001\046\001\028\001\029\001\023\001\010\001\011\001\
\047\001\047\001\014\001\008\001\023\001\012\001\035\000\036\000\
\037\000\097\001\039\000\040\000\005\001\051\001\022\001\046\001\
\047\001\048\001\049\001\057\001\001\001\059\001\053\001\022\001\
\055\001\056\001\046\001\002\001\008\001\035\001\022\001\060\000\
\035\001\064\001\065\001\034\001\051\001\052\001\035\001\054\001\
\045\001\035\001\057\001\058\001\059\001\046\001\075\000\076\000\
\047\001\048\001\049\001\050\001\051\001\052\001\085\001\054\001\
\058\001\056\001\057\001\058\001\059\001\001\001\012\001\008\001\
\035\001\045\001\097\001\035\001\099\001\049\001\035\001\100\000\
\005\001\053\001\035\001\015\001\016\001\017\001\023\001\035\001\
\035\001\023\001\023\001\063\001\064\001\065\001\026\001\032\001\
\028\001\029\001\006\001\036\001\037\001\038\001\039\001\023\001\
\097\001\023\001\099\001\044\001\080\001\023\001\005\001\039\001\
\084\001\085\001\051\001\052\001\044\001\054\001\030\001\023\001\
\057\001\058\001\059\001\051\001\052\001\006\001\054\001\099\001\
\149\000\057\001\058\001\059\001\035\001\154\000\155\000\156\000\
\030\001\109\001\159\000\030\001\112\001\113\001\034\001\006\001\
\034\001\166\000\167\000\168\000\006\001\023\001\006\001\035\001\
\005\001\174\000\175\000\176\000\177\000\178\000\035\001\030\001\
\030\001\182\000\183\000\001\001\002\001\003\001\030\001\006\001\
\005\001\007\001\008\001\009\001\034\001\005\001\034\001\034\001\
\022\001\015\001\016\001\017\001\006\001\006\001\034\001\021\001\
\005\001\023\001\005\001\035\001\026\001\027\001\028\001\029\001\
\005\001\005\001\032\001\033\001\217\000\005\001\036\001\035\001\
\035\001\039\001\035\001\005\001\035\001\045\001\044\001\035\001\
\046\001\000\000\113\000\035\001\035\001\051\001\052\001\035\001\
\054\001\035\001\001\001\057\001\058\001\059\001\001\001\006\001\
\003\001\034\001\012\001\034\001\007\001\008\001\009\001\035\001\
\015\001\016\001\017\001\034\001\015\001\016\001\017\001\034\001\
\023\001\113\000\021\001\026\001\023\001\028\001\029\001\026\001\
\027\001\028\001\029\001\076\000\035\001\032\001\033\001\088\000\
\050\001\036\001\063\001\060\001\039\001\255\255\084\001\046\001\
\255\255\044\001\255\255\046\001\255\255\255\255\255\255\255\255\
\051\001\052\001\255\255\054\001\255\255\255\255\057\001\058\001\
\059\001\046\001\047\001\048\001\049\001\255\255\023\001\255\255\
\053\001\255\255\055\001\056\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\255\255\255\255\040\001\
\041\001\042\001\043\001\255\255\045\001\255\255\255\255\001\001\
\255\255\003\001\255\255\255\255\255\255\007\001\008\001\009\001\
\085\001\058\001\059\001\255\255\255\255\015\001\016\001\017\001\
\255\255\255\255\255\255\021\001\097\001\023\001\099\001\255\255\
\026\001\027\001\028\001\029\001\255\255\255\255\032\001\033\001\
\255\255\255\255\036\001\255\255\255\255\039\001\255\255\255\255\
\255\255\255\255\044\001\255\255\046\001\255\255\255\255\255\255\
\255\255\051\001\052\001\255\255\054\001\255\255\255\255\057\001\
\058\001\059\001\001\001\255\255\003\001\255\255\255\255\255\255\
\007\001\008\001\009\001\255\255\255\255\255\255\255\255\255\255\
\015\001\016\001\017\001\255\255\008\001\255\255\021\001\255\255\
\023\001\255\255\255\255\026\001\027\001\028\001\029\001\255\255\
\255\255\032\001\033\001\023\001\255\255\036\001\255\255\255\255\
\039\001\255\255\255\255\255\255\032\001\044\001\255\255\046\001\
\036\001\255\255\255\255\039\001\051\001\052\001\255\255\054\001\
\044\001\255\255\057\001\058\001\059\001\255\255\255\255\051\001\
\052\001\255\255\054\001\001\001\002\001\057\001\058\001\059\001\
\006\001\007\001\255\255\255\255\255\255\255\255\012\001\255\255\
\255\255\015\001\016\001\017\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\001\001\026\001\027\001\028\001\029\001\
\006\001\007\001\255\255\255\255\255\255\035\001\255\255\255\255\
\255\255\015\001\016\001\017\001\255\255\255\255\255\255\255\255\
\046\001\023\001\255\255\001\001\026\001\027\001\028\001\029\001\
\006\001\007\001\255\255\255\255\255\255\035\001\255\255\255\255\
\255\255\015\001\016\001\017\001\255\255\255\255\255\255\255\255\
\046\001\023\001\255\255\255\255\026\001\027\001\028\001\029\001\
\255\255\255\255\255\255\001\001\002\001\035\001\255\255\255\255\
\006\001\007\001\255\255\255\255\255\255\255\255\255\255\255\255\
\046\001\015\001\016\001\017\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\026\001\027\001\028\001\029\001\
\255\255\255\255\255\255\001\001\002\001\035\001\255\255\001\001\
\255\255\007\001\255\255\255\255\006\001\007\001\012\001\255\255\
\046\001\015\001\016\001\017\001\255\255\015\001\016\001\017\001\
\255\255\255\255\255\255\255\255\026\001\027\001\028\001\029\001\
\026\001\027\001\028\001\029\001\255\255\035\001\255\255\001\001\
\002\001\035\001\255\255\255\255\001\001\007\001\255\255\255\255\
\046\001\006\001\007\001\255\255\046\001\015\001\016\001\017\001\
\255\255\255\255\015\001\016\001\017\001\255\255\255\255\255\255\
\026\001\027\001\028\001\029\001\255\255\026\001\027\001\028\001\
\029\001\035\001\255\255\255\255\001\001\255\255\035\001\255\255\
\255\255\006\001\007\001\255\255\046\001\255\255\255\255\255\255\
\255\255\046\001\015\001\016\001\017\001\002\001\255\255\255\255\
\255\255\006\001\007\001\255\255\001\001\026\001\027\001\028\001\
\029\001\006\001\015\001\016\001\017\001\255\255\035\001\255\255\
\255\255\255\255\015\001\016\001\017\001\026\001\027\001\028\001\
\029\001\046\001\023\001\022\001\255\255\026\001\035\001\028\001\
\029\001\255\255\255\255\255\255\255\255\255\255\035\001\255\255\
\255\255\046\001\255\255\255\255\255\255\255\255\255\255\255\255\
\023\001\046\001\255\255\255\255\047\001\048\001\049\001\050\001\
\051\001\052\001\023\001\054\001\255\255\056\001\057\001\058\001\
\059\001\040\001\041\001\042\001\043\001\255\255\045\001\036\001\
\255\255\255\255\039\001\255\255\255\255\255\255\255\255\044\001\
\255\255\255\255\255\255\058\001\059\001\255\255\051\001\052\001\
\255\255\054\001\001\001\002\001\057\001\058\001\059\001\006\001\
\007\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\015\001\016\001\017\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\026\001\027\001\028\001\029\001\255\255\
\255\255\255\255\255\255\255\255\035\001"

let yynames_const = "\
  AMPERSAND\000\
  AT_SIGN\000\
  CARET\000\
  CNF\000\
  COLON\000\
  COMMA\000\
  EQUALS\000\
  EXCLAMATION\000\
  DOUBLEEXCLAMATION\000\
  FOF\000\
  QMF\000\
  GETS\000\
  GREATER\000\
  HOF\000\
  IF\000\
  IFF\000\
  IMPLIES\000\
  INCLUDE_TOK\000\
  INPUT_CLAUSE\000\
  INPUT_FORMULA\000\
  LAMBDA\000\
  LBRKT\000\
  LPAREN\000\
  MAP_TO\000\
  MMINUS\000\
  NAMPERSAND\000\
  NEQUALS\000\
  NIFF\000\
  NVLINE\000\
  PERIOD\000\
  PPLUS\000\
  QUESTION\000\
  DOUBLEQUESTION\000\
  RBRKT\000\
  RPAREN\000\
  TILDE\000\
  BOX\000\
  DIAMOND\000\
  TOK_FALSE\000\
  TOK_I\000\
  TOK_O\000\
  TOK_INT\000\
  TOK_REAL\000\
  TOK_TRUE\000\
  TOK_TYPE\000\
  VLINE\000\
  EOF\000\
  DTHF\000\
  DFOF\000\
  DCNF\000\
  DFOT\000\
  Unrecognized\000\
  "

let yynames_block = "\
  Unsigned_integer\000\
  Signed_integer\000\
  Decimal_part\000\
  Real\000\
  Atomic_system_word\000\
  Distinct_object\000\
  Single_quoted\000\
  Upper_word\000\
  Lower_word\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'null) in
    Obj.repr(
# 164 "parser-hotptp/htparser.mly"
         ( reset () )
# 794 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'hof_annotated) in
    Obj.repr(
# 165 "parser-hotptp/htparser.mly"
                        ( (!terms,!sigma,!termroles) )
# 802 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'fof_annotated) in
    Obj.repr(
# 166 "parser-hotptp/htparser.mly"
                        ( (!terms,!sigma,!termroles) )
# 810 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cnf_annotated) in
    Obj.repr(
# 167 "parser-hotptp/htparser.mly"
                        ( (!terms,!sigma,!termroles) )
# 818 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_annotated) in
    Obj.repr(
# 168 "parser-hotptp/htparser.mly"
                        ( (!terms,!sigma,!termroles) )
# 826 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    Obj.repr(
# 169 "parser-hotptp/htparser.mly"
          ( let startpos = Parsing.rhs_start_pos 1 in
            let endpos = Parsing.rhs_end_pos 1
            in
              print_error startpos endpos "syntax error";
              raise PARSER )
# 836 "parser-hotptp/htparser.ml"
               : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'fof_top) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 178 "parser-hotptp/htparser.mly"
                                                                               (State.set_input_logic "FOF"; !add_fun _3 _5)
# 846 "parser-hotptp/htparser.ml"
               : 'fof_annotated))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'qmf_top) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 182 "parser-hotptp/htparser.mly"
                                                                               (State.set_input_logic "QMF"; !add_fun _3 _5)
# 856 "parser-hotptp/htparser.ml"
               : 'qmf_annotated))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'cnf_top) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 186 "parser-hotptp/htparser.mly"
                                                                               (State.set_input_logic "CNF"; !add_fun _3 _5)
# 866 "parser-hotptp/htparser.ml"
               : 'cnf_annotated))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 190 "parser-hotptp/htparser.mly"
              ( _1 )
# 873 "parser-hotptp/htparser.ml"
               : 'formula_role))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'source) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'optional_info) in
    Obj.repr(
# 194 "parser-hotptp/htparser.mly"
                               ()
# 881 "parser-hotptp/htparser.ml"
               : 'annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'null) in
    Obj.repr(
# 195 "parser-hotptp/htparser.mly"
         ()
# 888 "parser-hotptp/htparser.ml"
               : 'annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'general_term) in
    Obj.repr(
# 199 "parser-hotptp/htparser.mly"
                 ()
# 895 "parser-hotptp/htparser.ml"
               : 'source))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'general_data) in
    Obj.repr(
# 203 "parser-hotptp/htparser.mly"
                 ()
# 902 "parser-hotptp/htparser.ml"
               : 'general_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'general_data) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'general_term) in
    Obj.repr(
# 204 "parser-hotptp/htparser.mly"
                                    ()
# 910 "parser-hotptp/htparser.ml"
               : 'general_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'general_list) in
    Obj.repr(
# 205 "parser-hotptp/htparser.mly"
                 ()
# 917 "parser-hotptp/htparser.ml"
               : 'general_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 209 "parser-hotptp/htparser.mly"
                ()
# 924 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'atomic_word) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'general_terms) in
    Obj.repr(
# 210 "parser-hotptp/htparser.mly"
                                            ()
# 932 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable) in
    Obj.repr(
# 211 "parser-hotptp/htparser.mly"
             ()
# 939 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'number) in
    Obj.repr(
# 212 "parser-hotptp/htparser.mly"
           ()
# 946 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 213 "parser-hotptp/htparser.mly"
                    ()
# 953 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'formula_data) in
    Obj.repr(
# 214 "parser-hotptp/htparser.mly"
                 ()
# 960 "parser-hotptp/htparser.ml"
               : 'general_data))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'thf_logic_formula) in
    Obj.repr(
# 218 "parser-hotptp/htparser.mly"
                                         ()
# 967 "parser-hotptp/htparser.ml"
               : 'formula_data))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'fof_formula) in
    Obj.repr(
# 219 "parser-hotptp/htparser.mly"
                                   ()
# 974 "parser-hotptp/htparser.ml"
               : 'formula_data))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'cnf_formula) in
    Obj.repr(
# 220 "parser-hotptp/htparser.mly"
                                   ()
# 981 "parser-hotptp/htparser.ml"
               : 'formula_data))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'fof_term) in
    Obj.repr(
# 221 "parser-hotptp/htparser.mly"
                                ()
# 988 "parser-hotptp/htparser.ml"
               : 'formula_data))
; (fun __caml_parser_env ->
    Obj.repr(
# 225 "parser-hotptp/htparser.mly"
                ()
# 994 "parser-hotptp/htparser.ml"
               : 'general_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'general_terms) in
    Obj.repr(
# 226 "parser-hotptp/htparser.mly"
                              ()
# 1001 "parser-hotptp/htparser.ml"
               : 'general_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'general_term) in
    Obj.repr(
# 230 "parser-hotptp/htparser.mly"
                 ()
# 1008 "parser-hotptp/htparser.ml"
               : 'general_terms))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'general_term) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'general_terms) in
    Obj.repr(
# 231 "parser-hotptp/htparser.mly"
                                     ()
# 1016 "parser-hotptp/htparser.ml"
               : 'general_terms))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'useful_info) in
    Obj.repr(
# 235 "parser-hotptp/htparser.mly"
                      ()
# 1023 "parser-hotptp/htparser.ml"
               : 'optional_info))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'null) in
    Obj.repr(
# 236 "parser-hotptp/htparser.mly"
         ()
# 1030 "parser-hotptp/htparser.ml"
               : 'optional_info))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'general_list) in
    Obj.repr(
# 240 "parser-hotptp/htparser.mly"
                 ()
# 1037 "parser-hotptp/htparser.ml"
               : 'useful_info))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'typed_constant) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 247 "parser-hotptp/htparser.mly"
                                                                                      (State.set_input_logic "THF"; add_const _7; !add_fun _3 _5)
# 1047 "parser-hotptp/htparser.ml"
               : 'hof_annotated))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'definition) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 248 "parser-hotptp/htparser.mly"
                                                                                  (State.set_input_logic "THF"; add_def _7; reset_bound_typevars(); !add_fun _3 _5)
# 1057 "parser-hotptp/htparser.ml"
               : 'hof_annotated))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'name) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'formula_role) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'thf_logic_formula) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'annotations) in
    Obj.repr(
# 249 "parser-hotptp/htparser.mly"
                                                                                         (State.set_input_logic "THF";
            match (_5,_7) with
              ("definition",(Appl (Appl (Symbol "=", Symbol definiendum), definiens))) -> (add_def (definiendum,definiens);
                                                                                           reset_bound_typevars();
                                                                                           !add_fun _3 _5)
            | _ -> (add_term _7; reset_bound_typevars();!add_fun _3 _5))
# 1072 "parser-hotptp/htparser.ml"
               : 'hof_annotated))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 260 "parser-hotptp/htparser.mly"
         ( add_term _1; reset_bound_typevars() )
# 1079 "parser-hotptp/htparser.ml"
               : 'hof_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'definition) in
    Obj.repr(
# 261 "parser-hotptp/htparser.mly"
               ( add_def _1; reset_bound_typevars() )
# 1086 "parser-hotptp/htparser.ml"
               : 'hof_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'typed_constant) in
    Obj.repr(
# 262 "parser-hotptp/htparser.mly"
                   ( add_const_strict _1 )
# 1093 "parser-hotptp/htparser.ml"
               : 'hof_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'defined_element) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_logic_formula) in
    Obj.repr(
# 269 "parser-hotptp/htparser.mly"
                                           ( (_1,_3) )
# 1101 "parser-hotptp/htparser.ml"
               : 'definition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'defined_element) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'thf_logic_formula) in
    Obj.repr(
# 270 "parser-hotptp/htparser.mly"
                                                        ( (_2,_4) )
# 1109 "parser-hotptp/htparser.ml"
               : 'definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'constant) in
    Obj.repr(
# 275 "parser-hotptp/htparser.mly"
             ( _1 )
# 1116 "parser-hotptp/htparser.ml"
               : 'defined_element))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'typed_constant) in
    Obj.repr(
# 276 "parser-hotptp/htparser.mly"
                   ( fst _1 )
# 1123 "parser-hotptp/htparser.ml"
               : 'defined_element))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'constant) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'type_expr) in
    Obj.repr(
# 280 "parser-hotptp/htparser.mly"
                                           ( (_2,_4) )
# 1131 "parser-hotptp/htparser.ml"
               : 'typed_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'constant) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'type_expr) in
    Obj.repr(
# 281 "parser-hotptp/htparser.mly"
                             ( (_1,_3) )
# 1139 "parser-hotptp/htparser.ml"
               : 'typed_constant))
; (fun __caml_parser_env ->
    Obj.repr(
# 285 "parser-hotptp/htparser.mly"
             ( Signature.ctrue )
# 1145 "parser-hotptp/htparser.ml"
               : 'constant))
; (fun __caml_parser_env ->
    Obj.repr(
# 286 "parser-hotptp/htparser.mly"
              ( Signature.cfalse )
# 1151 "parser-hotptp/htparser.ml"
               : 'constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 287 "parser-hotptp/htparser.mly"
                ( _1 )
# 1158 "parser-hotptp/htparser.ml"
               : 'constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_formula) in
    Obj.repr(
# 292 "parser-hotptp/htparser.mly"
                ((* print_string ("Read: "^(Term.to_hotptp $1)^"\n\n"); *)
      add_term (multi_quantified (Symbol Signature.forall) (List.map (fun x -> (x,bt_i)) (free_vars _1)) _1);
      reset_bound_typevars() )
# 1167 "parser-hotptp/htparser.ml"
               : 'fof_top))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_formula) in
    Obj.repr(
# 299 "parser-hotptp/htparser.mly"
                ((* print_string ("Read: "^(Term.to_hotptp $1)^"\n\n"); *)
      add_term (multi_quantified (Symbol Signature.forall) (List.map (fun x -> (x,bt_i)) (free_vars _1)) _1);
      reset_bound_typevars() )
# 1176 "parser-hotptp/htparser.ml"
               : 'qmf_top))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cnf_formula) in
    Obj.repr(
# 306 "parser-hotptp/htparser.mly"
                (
      add_term (multi_quantified (Symbol Signature.forall) (List.map (fun x -> (x,bt_i)) (free_vars _1)) _1);
      reset_bound_typevars() )
# 1185 "parser-hotptp/htparser.ml"
               : 'cnf_top))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cnf_literal) in
    Obj.repr(
# 312 "parser-hotptp/htparser.mly"
                ( _1 )
# 1192 "parser-hotptp/htparser.ml"
               : 'cnf_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cnf_literal) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cnf_formula) in
    Obj.repr(
# 313 "parser-hotptp/htparser.mly"
                                  ( Appl(Appl(Symbol(Signature.disjunction),_1),_3) )
# 1200 "parser-hotptp/htparser.ml"
               : 'cnf_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'cnf_formula) in
    Obj.repr(
# 314 "parser-hotptp/htparser.mly"
                              ( _2 )
# 1207 "parser-hotptp/htparser.ml"
               : 'cnf_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_atomic_formula) in
    Obj.repr(
# 318 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1214 "parser-hotptp/htparser.ml"
               : 'cnf_literal))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'fof_atomic_formula) in
    Obj.repr(
# 319 "parser-hotptp/htparser.mly"
                             ( Appl(Symbol(Signature.neg),_2) )
# 1221 "parser-hotptp/htparser.ml"
               : 'cnf_literal))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 323 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1228 "parser-hotptp/htparser.ml"
               : 'fof_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_binary_formula) in
    Obj.repr(
# 324 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1235 "parser-hotptp/htparser.ml"
               : 'fof_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_nonassoc_binary) in
    Obj.repr(
# 328 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1242 "parser-hotptp/htparser.ml"
               : 'fof_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_assoc_binary) in
    Obj.repr(
# 329 "parser-hotptp/htparser.mly"
                     ( _1 )
# 1249 "parser-hotptp/htparser.ml"
               : 'fof_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_unitary_formula) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'fof_binary_connective) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 333 "parser-hotptp/htparser.mly"
                                                                  ( Appl(Appl(_2,_1),_3) )
# 1258 "parser-hotptp/htparser.ml"
               : 'fof_nonassoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_and_formula) in
    Obj.repr(
# 337 "parser-hotptp/htparser.mly"
                    ( _1 )
# 1265 "parser-hotptp/htparser.ml"
               : 'fof_assoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_or_formula) in
    Obj.repr(
# 338 "parser-hotptp/htparser.mly"
                   ( _1 )
# 1272 "parser-hotptp/htparser.ml"
               : 'fof_assoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_unitary_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 342 "parser-hotptp/htparser.mly"
                                                     ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1280 "parser-hotptp/htparser.ml"
               : 'fof_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_and_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 343 "parser-hotptp/htparser.mly"
                                                  ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1288 "parser-hotptp/htparser.ml"
               : 'fof_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_or_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 347 "parser-hotptp/htparser.mly"
                                             ( Appl(Appl(Symbol(Signature.disjunction),_1),_3) )
# 1296 "parser-hotptp/htparser.ml"
               : 'fof_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 348 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1303 "parser-hotptp/htparser.ml"
               : 'fof_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_quantified_formula) in
    Obj.repr(
# 352 "parser-hotptp/htparser.mly"
                           ( _1 )
# 1310 "parser-hotptp/htparser.ml"
               : 'fof_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unary_formula) in
    Obj.repr(
# 353 "parser-hotptp/htparser.mly"
                      ( _1 )
# 1317 "parser-hotptp/htparser.ml"
               : 'fof_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_atomic_formula) in
    Obj.repr(
# 354 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1324 "parser-hotptp/htparser.ml"
               : 'fof_unitary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'fof_formula) in
    Obj.repr(
# 355 "parser-hotptp/htparser.mly"
                              ( _2 )
# 1331 "parser-hotptp/htparser.ml"
               : 'fof_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'quantifier) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'fof_variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 359 "parser-hotptp/htparser.mly"
                                                                        ( multi_quantified _1 _3 _6 )
# 1340 "parser-hotptp/htparser.ml"
               : 'fof_quantified_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_variable_decl) in
    Obj.repr(
# 363 "parser-hotptp/htparser.mly"
                      ( [_1] )
# 1347 "parser-hotptp/htparser.ml"
               : 'fof_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_variable_decl) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_variable_decls) in
    Obj.repr(
# 364 "parser-hotptp/htparser.mly"
                                               ( _1::_3 )
# 1355 "parser-hotptp/htparser.ml"
               : 'fof_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_variable) in
    Obj.repr(
# 368 "parser-hotptp/htparser.mly"
                 ( (_1,bt_i) )
# 1362 "parser-hotptp/htparser.ml"
               : 'fof_variable_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'fof_unary_connective) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'fof_unitary_formula) in
    Obj.repr(
# 372 "parser-hotptp/htparser.mly"
                                             ( Appl(_1,_2) )
# 1370 "parser-hotptp/htparser.ml"
               : 'fof_unary_formula))
; (fun __caml_parser_env ->
    Obj.repr(
# 376 "parser-hotptp/htparser.mly"
          ( Symbol(Signature.neg) )
# 1376 "parser-hotptp/htparser.ml"
               : 'fof_unary_connective))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_prop_const) in
    Obj.repr(
# 380 "parser-hotptp/htparser.mly"
                   ( Symbol _1 )
# 1383 "parser-hotptp/htparser.ml"
               : 'fof_atomic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_term) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'fof_infix_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_term) in
    Obj.repr(
# 381 "parser-hotptp/htparser.mly"
                                     ( Appl(Appl(_2,_1),_3) )
# 1392 "parser-hotptp/htparser.ml"
               : 'fof_atomic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'fof_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'fof_args) in
    Obj.repr(
# 385 "parser-hotptp/htparser.mly"
                                    ( (* print_string ("fof_pred "^(Term.to_hotptp $1)^" with args ");
                                      List.map (fun a -> print_string ((Term.to_hotptp a)^", ")) $3;
                                      print_string "\n"; *)
      add_const (get_symbol _1, mk_funtype (List.map (fun _ -> bt_i) _3) bt_o);
      List.fold_left (fun acc arg -> Appl(acc,arg)) _1 _3 )
# 1404 "parser-hotptp/htparser.ml"
               : 'fof_atomic_formula))
; (fun __caml_parser_env ->
    Obj.repr(
# 393 "parser-hotptp/htparser.mly"
             ( Signature.ctrue )
# 1410 "parser-hotptp/htparser.ml"
               : 'fof_prop_const))
; (fun __caml_parser_env ->
    Obj.repr(
# 394 "parser-hotptp/htparser.mly"
              ( Signature.cfalse )
# 1416 "parser-hotptp/htparser.ml"
               : 'fof_prop_const))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 395 "parser-hotptp/htparser.mly"
                ( add_const (_1,bt_o); _1 )
# 1423 "parser-hotptp/htparser.ml"
               : 'fof_prop_const))
; (fun __caml_parser_env ->
    Obj.repr(
# 399 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.equality) )
# 1429 "parser-hotptp/htparser.ml"
               : 'fof_infix_pred))
; (fun __caml_parser_env ->
    Obj.repr(
# 400 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.nequals) )
# 1435 "parser-hotptp/htparser.ml"
               : 'fof_infix_pred))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_term) in
    Obj.repr(
# 404 "parser-hotptp/htparser.mly"
             ( [_1] )
# 1442 "parser-hotptp/htparser.ml"
               : 'fof_args))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'fof_term) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'fof_args) in
    Obj.repr(
# 405 "parser-hotptp/htparser.mly"
                            ( _1::_3 )
# 1450 "parser-hotptp/htparser.ml"
               : 'fof_args))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_constant) in
    Obj.repr(
# 409 "parser-hotptp/htparser.mly"
                 ( _1 )
# 1457 "parser-hotptp/htparser.ml"
               : 'fof_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'fof_variable) in
    Obj.repr(
# 410 "parser-hotptp/htparser.mly"
                 ( Symbol _1 )
# 1464 "parser-hotptp/htparser.ml"
               : 'fof_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'fof_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'fof_args) in
    Obj.repr(
# 412 "parser-hotptp/htparser.mly"
                                    (
      add_const (get_symbol _1, mk_funtype (List.map (fun _ -> bt_i) _3) bt_i);
      List.fold_left (fun acc arg -> Appl(acc,arg)) _1 _3 )
# 1474 "parser-hotptp/htparser.ml"
               : 'fof_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 418 "parser-hotptp/htparser.mly"
                ( (* print_string ("There's a constant of type $i: "^$1^"\n"); *) add_const (_1, bt_i);
      Symbol _1 )
# 1482 "parser-hotptp/htparser.ml"
               : 'fof_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'number) in
    Obj.repr(
# 420 "parser-hotptp/htparser.mly"
           ( Symbol _1 )
# 1489 "parser-hotptp/htparser.ml"
               : 'fof_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable) in
    Obj.repr(
# 424 "parser-hotptp/htparser.mly"
             ( _1 )
# 1496 "parser-hotptp/htparser.ml"
               : 'fof_variable))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 434 "parser-hotptp/htparser.mly"
                ( Symbol _1 )
# 1503 "parser-hotptp/htparser.ml"
               : 'fof_pred))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 439 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1510 "parser-hotptp/htparser.ml"
               : 'qmf_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_binary_formula) in
    Obj.repr(
# 440 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1517 "parser-hotptp/htparser.ml"
               : 'qmf_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_nonassoc_binary) in
    Obj.repr(
# 444 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1524 "parser-hotptp/htparser.ml"
               : 'qmf_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_assoc_binary) in
    Obj.repr(
# 445 "parser-hotptp/htparser.mly"
                     ( _1 )
# 1531 "parser-hotptp/htparser.ml"
               : 'qmf_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_unitary_formula) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'fof_binary_connective) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 449 "parser-hotptp/htparser.mly"
                                                                  ( Appl(Appl(_2,_1),_3) )
# 1540 "parser-hotptp/htparser.ml"
               : 'qmf_nonassoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_and_formula) in
    Obj.repr(
# 453 "parser-hotptp/htparser.mly"
                    ( _1 )
# 1547 "parser-hotptp/htparser.ml"
               : 'qmf_assoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_or_formula) in
    Obj.repr(
# 454 "parser-hotptp/htparser.mly"
                   ( _1 )
# 1554 "parser-hotptp/htparser.ml"
               : 'qmf_assoc_binary))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_unitary_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 458 "parser-hotptp/htparser.mly"
                                                     ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1562 "parser-hotptp/htparser.ml"
               : 'qmf_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_and_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 459 "parser-hotptp/htparser.mly"
                                                  ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1570 "parser-hotptp/htparser.ml"
               : 'qmf_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_or_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 463 "parser-hotptp/htparser.mly"
                                             ( Appl(Appl(Symbol(Signature.disjunction),_1),_3) )
# 1578 "parser-hotptp/htparser.ml"
               : 'qmf_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 464 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1585 "parser-hotptp/htparser.ml"
               : 'qmf_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_quantified_formula) in
    Obj.repr(
# 468 "parser-hotptp/htparser.mly"
                           ( _1 )
# 1592 "parser-hotptp/htparser.ml"
               : 'qmf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unary_formula) in
    Obj.repr(
# 469 "parser-hotptp/htparser.mly"
                      ( _1 )
# 1599 "parser-hotptp/htparser.ml"
               : 'qmf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_atomic_formula) in
    Obj.repr(
# 470 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1606 "parser-hotptp/htparser.ml"
               : 'qmf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_boxed_formula) in
    Obj.repr(
# 471 "parser-hotptp/htparser.mly"
                      ( _1 )
# 1613 "parser-hotptp/htparser.ml"
               : 'qmf_unitary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'qmf_formula) in
    Obj.repr(
# 472 "parser-hotptp/htparser.mly"
                              ( _2 )
# 1620 "parser-hotptp/htparser.ml"
               : 'qmf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'boxoperator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 476 "parser-hotptp/htparser.mly"
                                          ( Appl(_1,_3) )
# 1628 "parser-hotptp/htparser.ml"
               : 'qmf_boxed_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'quantifier) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'qmf_variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 480 "parser-hotptp/htparser.mly"
                                                                        ( multi_quantified _1 _3 _6 )
# 1637 "parser-hotptp/htparser.ml"
               : 'qmf_quantified_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_variable_decl) in
    Obj.repr(
# 484 "parser-hotptp/htparser.mly"
                      ( [_1] )
# 1644 "parser-hotptp/htparser.ml"
               : 'qmf_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_variable_decl) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_variable_decls) in
    Obj.repr(
# 485 "parser-hotptp/htparser.mly"
                                               ( _1::_3 )
# 1652 "parser-hotptp/htparser.ml"
               : 'qmf_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_variable) in
    Obj.repr(
# 489 "parser-hotptp/htparser.mly"
                 ( (_1,bt_i) )
# 1659 "parser-hotptp/htparser.ml"
               : 'qmf_variable_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'qmf_unary_connective) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_unitary_formula) in
    Obj.repr(
# 493 "parser-hotptp/htparser.mly"
                                             ( Appl(_1,_2) )
# 1667 "parser-hotptp/htparser.ml"
               : 'qmf_unary_formula))
; (fun __caml_parser_env ->
    Obj.repr(
# 497 "parser-hotptp/htparser.mly"
          ( Symbol(Signature.neg) )
# 1673 "parser-hotptp/htparser.ml"
               : 'qmf_unary_connective))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_prop_const) in
    Obj.repr(
# 501 "parser-hotptp/htparser.mly"
                   ( Symbol _1 )
# 1680 "parser-hotptp/htparser.ml"
               : 'qmf_atomic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_term) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'qmf_infix_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_term) in
    Obj.repr(
# 502 "parser-hotptp/htparser.mly"
                                     ( Appl(Appl(_2,_1),_3) )
# 1689 "parser-hotptp/htparser.ml"
               : 'qmf_atomic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'qmf_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'qmf_args) in
    Obj.repr(
# 506 "parser-hotptp/htparser.mly"
                                    ( (* print_string ("qmf_pred "^(Term.to_hotptp $1)^" with args ");
                                      List.map (fun a -> print_string ((Term.to_hotptp a)^", ")) $3;
                                      print_string "\n"; *)
      add_const (get_symbol _1, mk_funtype (List.map (fun _ -> bt_i) _3) bt_o);
      List.fold_left (fun acc arg -> Appl(acc,arg)) _1 _3 )
# 1701 "parser-hotptp/htparser.ml"
               : 'qmf_atomic_formula))
; (fun __caml_parser_env ->
    Obj.repr(
# 514 "parser-hotptp/htparser.mly"
             ( Signature.ctrue )
# 1707 "parser-hotptp/htparser.ml"
               : 'qmf_prop_const))
; (fun __caml_parser_env ->
    Obj.repr(
# 515 "parser-hotptp/htparser.mly"
              ( Signature.cfalse )
# 1713 "parser-hotptp/htparser.ml"
               : 'qmf_prop_const))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 516 "parser-hotptp/htparser.mly"
                ( add_const (_1,bt_o); _1 )
# 1720 "parser-hotptp/htparser.ml"
               : 'qmf_prop_const))
; (fun __caml_parser_env ->
    Obj.repr(
# 520 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.equality) )
# 1726 "parser-hotptp/htparser.ml"
               : 'qmf_infix_pred))
; (fun __caml_parser_env ->
    Obj.repr(
# 521 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.nequals) )
# 1732 "parser-hotptp/htparser.ml"
               : 'qmf_infix_pred))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_term) in
    Obj.repr(
# 525 "parser-hotptp/htparser.mly"
             ( [_1] )
# 1739 "parser-hotptp/htparser.ml"
               : 'qmf_args))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qmf_term) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_args) in
    Obj.repr(
# 526 "parser-hotptp/htparser.mly"
                            ( _1::_3 )
# 1747 "parser-hotptp/htparser.ml"
               : 'qmf_args))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_constant) in
    Obj.repr(
# 530 "parser-hotptp/htparser.mly"
                 ( _1 )
# 1754 "parser-hotptp/htparser.ml"
               : 'qmf_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qmf_variable) in
    Obj.repr(
# 531 "parser-hotptp/htparser.mly"
                 ( Symbol _1 )
# 1761 "parser-hotptp/htparser.ml"
               : 'qmf_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'qmf_pred) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'qmf_args) in
    Obj.repr(
# 533 "parser-hotptp/htparser.mly"
                                    (
      add_const (get_symbol _1, mk_funtype (List.map (fun _ -> bt_i) _3) bt_i);
      List.fold_left (fun acc arg -> Appl(acc,arg)) _1 _3 )
# 1771 "parser-hotptp/htparser.ml"
               : 'qmf_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 539 "parser-hotptp/htparser.mly"
                ( (* print_string ("There's a constant of type $i: "^$1^"\n"); *) add_const (_1, bt_i);
      Symbol _1 )
# 1779 "parser-hotptp/htparser.ml"
               : 'qmf_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'number) in
    Obj.repr(
# 541 "parser-hotptp/htparser.mly"
           ( Symbol _1 )
# 1786 "parser-hotptp/htparser.ml"
               : 'qmf_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable) in
    Obj.repr(
# 545 "parser-hotptp/htparser.mly"
             ( _1 )
# 1793 "parser-hotptp/htparser.ml"
               : 'qmf_variable))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 555 "parser-hotptp/htparser.mly"
                ( Symbol _1 )
# 1800 "parser-hotptp/htparser.ml"
               : 'qmf_pred))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_binary_formula) in
    Obj.repr(
# 559 "parser-hotptp/htparser.mly"
                       ( _1 )
# 1807 "parser-hotptp/htparser.ml"
               : 'thf_logic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 560 "parser-hotptp/htparser.mly"
                        ( _1 )
# 1814 "parser-hotptp/htparser.ml"
               : 'thf_logic_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_binary_pair) in
    Obj.repr(
# 565 "parser-hotptp/htparser.mly"
                    ( _1 )
# 1821 "parser-hotptp/htparser.ml"
               : 'thf_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_binary_tuple) in
    Obj.repr(
# 566 "parser-hotptp/htparser.mly"
                     ( _1 )
# 1828 "parser-hotptp/htparser.ml"
               : 'thf_binary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_unitary_formula) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'thf_pair_connective) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 570 "parser-hotptp/htparser.mly"
                                                                ( Appl(Appl(_2,_1),_3) )
# 1837 "parser-hotptp/htparser.ml"
               : 'thf_binary_pair))
; (fun __caml_parser_env ->
    Obj.repr(
# 574 "parser-hotptp/htparser.mly"
        ( Symbol(Signature.iff) )
# 1843 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 575 "parser-hotptp/htparser.mly"
         ( Symbol(Signature.negated_iff) )
# 1849 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 576 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.implies) )
# 1855 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 577 "parser-hotptp/htparser.mly"
       ( Symbol(Signature.i_f) )
# 1861 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 578 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.negated_disjunction) )
# 1867 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 579 "parser-hotptp/htparser.mly"
               ( Symbol(Signature.negated_conjunction) )
# 1873 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 580 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.equality) )
# 1879 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 581 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.nequals) )
# 1885 "parser-hotptp/htparser.ml"
               : 'thf_pair_connective))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_or_formula) in
    Obj.repr(
# 586 "parser-hotptp/htparser.mly"
                   ( _1 )
# 1892 "parser-hotptp/htparser.ml"
               : 'thf_binary_tuple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_and_formula) in
    Obj.repr(
# 587 "parser-hotptp/htparser.mly"
                    ( _1 )
# 1899 "parser-hotptp/htparser.ml"
               : 'thf_binary_tuple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_apply_formula) in
    Obj.repr(
# 588 "parser-hotptp/htparser.mly"
                      ( _1 )
# 1906 "parser-hotptp/htparser.ml"
               : 'thf_binary_tuple))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_unitary_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 592 "parser-hotptp/htparser.mly"
                                                  ( Appl(Appl(Symbol(Signature.disjunction),_1),_3) )
# 1914 "parser-hotptp/htparser.ml"
               : 'thf_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_or_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 593 "parser-hotptp/htparser.mly"
                                             ( Appl(Appl(Symbol(Signature.disjunction),_1),_3) )
# 1922 "parser-hotptp/htparser.ml"
               : 'thf_or_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_unitary_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 597 "parser-hotptp/htparser.mly"
                                                      ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1930 "parser-hotptp/htparser.ml"
               : 'thf_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_and_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 598 "parser-hotptp/htparser.mly"
                                                  ( Appl(Appl(Symbol(Signature.conjunction),_1),_3) )
# 1938 "parser-hotptp/htparser.ml"
               : 'thf_and_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_unitary_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 602 "parser-hotptp/htparser.mly"
                                                    ( Appl(_1,_3) )
# 1946 "parser-hotptp/htparser.ml"
               : 'thf_apply_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'thf_apply_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 603 "parser-hotptp/htparser.mly"
                                                  ( Appl(_1,_3) )
# 1954 "parser-hotptp/htparser.ml"
               : 'thf_apply_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_quantified_formula) in
    Obj.repr(
# 607 "parser-hotptp/htparser.mly"
                           ( _1 )
# 1961 "parser-hotptp/htparser.ml"
               : 'thf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_abstraction) in
    Obj.repr(
# 608 "parser-hotptp/htparser.mly"
                    ( _1 )
# 1968 "parser-hotptp/htparser.ml"
               : 'thf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unary_formula) in
    Obj.repr(
# 609 "parser-hotptp/htparser.mly"
                      ( _1 )
# 1975 "parser-hotptp/htparser.ml"
               : 'thf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'thf_atom) in
    Obj.repr(
# 610 "parser-hotptp/htparser.mly"
             ( _1 )
# 1982 "parser-hotptp/htparser.ml"
               : 'thf_unitary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'thf_logic_formula) in
    Obj.repr(
# 613 "parser-hotptp/htparser.mly"
                                    ( _2 )
# 1989 "parser-hotptp/htparser.ml"
               : 'thf_unitary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'quantifier) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 617 "parser-hotptp/htparser.mly"
                                                                    ( multi_quantified _1 _3 _6 )
# 1998 "parser-hotptp/htparser.ml"
               : 'thf_quantified_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'lambda_symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 621 "parser-hotptp/htparser.mly"
                                                                       ( multi_abstr _3 _6 )
# 2007 "parser-hotptp/htparser.ml"
               : 'thf_abstraction))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'lambda_symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'type_variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'thf_unitary_formula) in
    Obj.repr(
# 622 "parser-hotptp/htparser.mly"
                                                                            ( _6 )
# 2016 "parser-hotptp/htparser.ml"
               : 'thf_abstraction))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'thf_logic_formula) in
    Obj.repr(
# 626 "parser-hotptp/htparser.mly"
                                          ( Appl(Symbol(Signature.neg),_3) )
# 2023 "parser-hotptp/htparser.ml"
               : 'thf_unary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'quantifier_comb) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'thf_logic_formula) in
    Obj.repr(
# 627 "parser-hotptp/htparser.mly"
                                      ( Appl(_1, _2) )
# 2031 "parser-hotptp/htparser.ml"
               : 'thf_unary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'quantifier_comb) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'thf_logic_formula) in
    Obj.repr(
# 628 "parser-hotptp/htparser.mly"
                                              ( Appl(_1, _3) )
# 2039 "parser-hotptp/htparser.ml"
               : 'thf_unary_formula))
; (fun __caml_parser_env ->
    Obj.repr(
# 632 "parser-hotptp/htparser.mly"
                      ( Symbol(Signature.forall_comb) )
# 2045 "parser-hotptp/htparser.ml"
               : 'quantifier_comb))
; (fun __caml_parser_env ->
    Obj.repr(
# 633 "parser-hotptp/htparser.mly"
                   ( Symbol(Signature.exists_comb) )
# 2051 "parser-hotptp/htparser.ml"
               : 'quantifier_comb))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable) in
    Obj.repr(
# 637 "parser-hotptp/htparser.mly"
             ( Symbol _1 )
# 2058 "parser-hotptp/htparser.ml"
               : 'thf_atom))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'constant) in
    Obj.repr(
# 638 "parser-hotptp/htparser.mly"
             ( Symbol _1 )
# 2065 "parser-hotptp/htparser.ml"
               : 'thf_atom))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'number) in
    Obj.repr(
# 639 "parser-hotptp/htparser.mly"
           ( Symbol _1 )
# 2072 "parser-hotptp/htparser.ml"
               : 'thf_atom))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'binary_connective) in
    Obj.repr(
# 640 "parser-hotptp/htparser.mly"
                      ( _1 )
# 2079 "parser-hotptp/htparser.ml"
               : 'thf_atom))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_connective) in
    Obj.repr(
# 641 "parser-hotptp/htparser.mly"
                     ( _1 )
# 2086 "parser-hotptp/htparser.ml"
               : 'thf_atom))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'lambda_term) in
    Obj.repr(
# 650 "parser-hotptp/htparser.mly"
                ( _1 )
# 2093 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'apply_term) in
    Obj.repr(
# 651 "parser-hotptp/htparser.mly"
               ( _1 )
# 2100 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'term) in
    Obj.repr(
# 652 "parser-hotptp/htparser.mly"
                       ( _2 )
# 2107 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable) in
    Obj.repr(
# 653 "parser-hotptp/htparser.mly"
             ( Symbol _1 )
# 2114 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'constant) in
    Obj.repr(
# 654 "parser-hotptp/htparser.mly"
             ( Symbol _1 )
# 2121 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'quantified_term) in
    Obj.repr(
# 655 "parser-hotptp/htparser.mly"
                    ( _1 )
# 2128 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'unary_connective) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 656 "parser-hotptp/htparser.mly"
                          ( Appl(_1,_2) )
# 2136 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'term) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'binary_connective) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 657 "parser-hotptp/htparser.mly"
                                ( Appl(Appl(_2,_1),_3) )
# 2145 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'number) in
    Obj.repr(
# 658 "parser-hotptp/htparser.mly"
           ( Symbol _1 )
# 2152 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'binary_connective) in
    Obj.repr(
# 659 "parser-hotptp/htparser.mly"
                      ( _1 )
# 2159 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_connective) in
    Obj.repr(
# 660 "parser-hotptp/htparser.mly"
                     ( _1 )
# 2166 "parser-hotptp/htparser.ml"
               : 'term))
; (fun __caml_parser_env ->
    Obj.repr(
# 664 "parser-hotptp/htparser.mly"
          ( Symbol(Signature.neg) )
# 2172 "parser-hotptp/htparser.ml"
               : 'unary_connective))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'quantifier_comb) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'thf_logic_formula) in
    Obj.repr(
# 665 "parser-hotptp/htparser.mly"
                                      ( Appl(_1, _2) )
# 2180 "parser-hotptp/htparser.ml"
               : 'unary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 669 "parser-hotptp/htparser.mly"
        ( Symbol(Signature.iff) )
# 2186 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 670 "parser-hotptp/htparser.mly"
         ( Symbol(Signature.negated_iff) )
# 2192 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 671 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.implies) )
# 2198 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 672 "parser-hotptp/htparser.mly"
       ( Symbol(Signature.i_f) )
# 2204 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 673 "parser-hotptp/htparser.mly"
          ( Symbol(Signature.disjunction) )
# 2210 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 674 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.negated_disjunction) )
# 2216 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 675 "parser-hotptp/htparser.mly"
              ( Symbol(Signature.conjunction) )
# 2222 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 676 "parser-hotptp/htparser.mly"
               ( Symbol(Signature.negated_conjunction) )
# 2228 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 677 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.equality) )
# 2234 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 678 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.nequals) )
# 2240 "parser-hotptp/htparser.ml"
               : 'binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 682 "parser-hotptp/htparser.mly"
        ( Symbol(Signature.iff) )
# 2246 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 683 "parser-hotptp/htparser.mly"
         ( Symbol(Signature.negated_iff) )
# 2252 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 684 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.implies) )
# 2258 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 685 "parser-hotptp/htparser.mly"
       ( Symbol(Signature.i_f) )
# 2264 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 686 "parser-hotptp/htparser.mly"
           ( Symbol(Signature.negated_disjunction) )
# 2270 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    Obj.repr(
# 687 "parser-hotptp/htparser.mly"
               ( Symbol(Signature.negated_conjunction) )
# 2276 "parser-hotptp/htparser.ml"
               : 'fof_binary_connective))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'quantifier) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 691 "parser-hotptp/htparser.mly"
                                                     ( multi_quantified _1 _3 _6 )
# 2285 "parser-hotptp/htparser.ml"
               : 'quantified_term))
; (fun __caml_parser_env ->
    Obj.repr(
# 695 "parser-hotptp/htparser.mly"
                ( Symbol(Signature.forall) )
# 2291 "parser-hotptp/htparser.ml"
               : 'quantifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 696 "parser-hotptp/htparser.mly"
             ( Symbol(Signature.exists) )
# 2297 "parser-hotptp/htparser.ml"
               : 'quantifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 700 "parser-hotptp/htparser.mly"
        ( Symbol(Signature.box) )
# 2303 "parser-hotptp/htparser.ml"
               : 'boxoperator))
; (fun __caml_parser_env ->
    Obj.repr(
# 701 "parser-hotptp/htparser.mly"
            ( Symbol(Signature.diamond) )
# 2309 "parser-hotptp/htparser.ml"
               : 'boxoperator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'term) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 705 "parser-hotptp/htparser.mly"
                      ( Appl(_1,_3) )
# 2317 "parser-hotptp/htparser.ml"
               : 'apply_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'lambda_symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 709 "parser-hotptp/htparser.mly"
                                                        ( multi_abstr _3 _6 )
# 2326 "parser-hotptp/htparser.ml"
               : 'lambda_term))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'lambda_symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'type_variable_decls) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'term) in
    Obj.repr(
# 710 "parser-hotptp/htparser.mly"
                                                             ( _6 )
# 2335 "parser-hotptp/htparser.ml"
               : 'lambda_term))
; (fun __caml_parser_env ->
    Obj.repr(
# 714 "parser-hotptp/htparser.mly"
           ( )
# 2341 "parser-hotptp/htparser.ml"
               : 'lambda_symbol))
; (fun __caml_parser_env ->
    Obj.repr(
# 715 "parser-hotptp/htparser.mly"
          ( )
# 2347 "parser-hotptp/htparser.ml"
               : 'lambda_symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'variable_decl) in
    Obj.repr(
# 720 "parser-hotptp/htparser.mly"
                  ( [_1] )
# 2354 "parser-hotptp/htparser.ml"
               : 'variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'variable_decl) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'variable_decls) in
    Obj.repr(
# 721 "parser-hotptp/htparser.mly"
                                       ( _1::_3 )
# 2362 "parser-hotptp/htparser.ml"
               : 'variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'variable) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'type_expr) in
    Obj.repr(
# 725 "parser-hotptp/htparser.mly"
                             ( (_1,_3) )
# 2370 "parser-hotptp/htparser.ml"
               : 'variable_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'type_variable_decl) in
    Obj.repr(
# 729 "parser-hotptp/htparser.mly"
                       ( )
# 2377 "parser-hotptp/htparser.ml"
               : 'type_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'type_variable_decl) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'type_variable_decls) in
    Obj.repr(
# 730 "parser-hotptp/htparser.mly"
                                                 ( )
# 2385 "parser-hotptp/htparser.ml"
               : 'type_variable_decls))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'variable) in
    Obj.repr(
# 734 "parser-hotptp/htparser.mly"
                            ( add_typevar _1 )
# 2392 "parser-hotptp/htparser.ml"
               : 'type_variable_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_type) in
    Obj.repr(
# 738 "parser-hotptp/htparser.mly"
                ( _1 )
# 2399 "parser-hotptp/htparser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'type_variable) in
    Obj.repr(
# 739 "parser-hotptp/htparser.mly"
                  ( if Hashtbl.mem !bound_typevars _1 then mk_polyvar (Hashtbl.find !bound_typevars _1) else basetype _1  )
# 2406 "parser-hotptp/htparser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'poly_type_variable) in
    Obj.repr(
# 740 "parser-hotptp/htparser.mly"
                       ( basetype _1 )
# 2413 "parser-hotptp/htparser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'map_arrow) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'type_expr) in
    Obj.repr(
# 741 "parser-hotptp/htparser.mly"
                                  ( abstr_type _1 _3 )
# 2422 "parser-hotptp/htparser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'type_expr) in
    Obj.repr(
# 742 "parser-hotptp/htparser.mly"
                            ( _2 )
# 2429 "parser-hotptp/htparser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    Obj.repr(
# 746 "parser-hotptp/htparser.mly"
          ( bt_o )
# 2435 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 747 "parser-hotptp/htparser.mly"
          ( bt_i )
# 2441 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 748 "parser-hotptp/htparser.mly"
            ( basetype "$int" )
# 2447 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 749 "parser-hotptp/htparser.mly"
             ( basetype "$real" )
# 2453 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 750 "parser-hotptp/htparser.mly"
             ( bt_type )
# 2459 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 751 "parser-hotptp/htparser.mly"
               ( basetype _1 )
# 2466 "parser-hotptp/htparser.ml"
               : 'atomic_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 755 "parser-hotptp/htparser.mly"
              ( _1 )
# 2473 "parser-hotptp/htparser.ml"
               : 'type_variable))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 759 "parser-hotptp/htparser.mly"
               ( _1 )
# 2480 "parser-hotptp/htparser.ml"
               : 'poly_type_variable))
; (fun __caml_parser_env ->
    Obj.repr(
# 764 "parser-hotptp/htparser.mly"
           ( )
# 2486 "parser-hotptp/htparser.ml"
               : 'map_arrow))
; (fun __caml_parser_env ->
    Obj.repr(
# 765 "parser-hotptp/htparser.mly"
             ( )
# 2492 "parser-hotptp/htparser.ml"
               : 'map_arrow))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'atomic_word) in
    Obj.repr(
# 769 "parser-hotptp/htparser.mly"
                ( _1 )
# 2499 "parser-hotptp/htparser.ml"
               : 'name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 770 "parser-hotptp/htparser.mly"
                     ( _1 )
# 2506 "parser-hotptp/htparser.ml"
               : 'name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 774 "parser-hotptp/htparser.mly"
               ( _1 )
# 2513 "parser-hotptp/htparser.ml"
               : 'atomic_word))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 775 "parser-hotptp/htparser.mly"
                  ( _1 )
# 2520 "parser-hotptp/htparser.ml"
               : 'atomic_word))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 779 "parser-hotptp/htparser.mly"
               ( _1 )
# 2527 "parser-hotptp/htparser.ml"
               : 'variable))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 783 "parser-hotptp/htparser.mly"
                     ( add_const (_1, basetype "$int");  _1 )
# 2534 "parser-hotptp/htparser.ml"
               : 'number))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 784 "parser-hotptp/htparser.mly"
                   ( add_const (_1, basetype "$int"); _1 )
# 2541 "parser-hotptp/htparser.ml"
               : 'number))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 785 "parser-hotptp/htparser.mly"
         ( add_const (_1, basetype "$real"); _1 )
# 2548 "parser-hotptp/htparser.ml"
               : 'number))
; (fun __caml_parser_env ->
    Obj.repr(
# 787 "parser-hotptp/htparser.mly"
       ()
# 2554 "parser-hotptp/htparser.ml"
               : 'null))
(* Entry input *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let input (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Term.term list * Signature.signature * (string , string * Term.term) Hashtbl.t)
